from setuptools import setup, find_packages

setup(
    name="translate_package",
    version="0.3.4",
    author="Oumar Kane",
    packages=find_packages(),
    author_email="oumar.kane@univ-thies.sn",
    description="Contain functions and classes to efficiently train a sequence to sequence to translate between two languages.",
    install_requires=[
        "accelerate==1.12.0",
        "torch==2.7.0",
        "torchvision==0.22.0",
        "spacy==3.8.11",
        "nltk==3.9.2",
        "gensim==4.4.0",
        "furo==2025.12.19",
        "streamlit==1.54.0",
        "tokenizers==0.22.2",
        "tensorboard==2.20.0",
        "evaluate==0.4.6",
        "transformers==5.0.0",
        "pandas==2.3.3",
        "scikit-learn",
        "matplotlib==3.10.8",
        "plotly==6.5.2",
        "sacrebleu==2.6.0",
        "nlpaug==1.1.11",
        "wandb==0.24.2",
        "pytorch-lightning==2.6.1",
        "selenium==4.40.0",
        "sentencepiece",
        "peft==0.18.1",
        "rouge-score==0.1.2",
        "wolof-translate==0.0.6",
        "fasttext",
        "numpy",
    ],
)
